## ----setup, include = FALSE----------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)

## ------------------------------------------------------------------------
library(ProcMod)

## ------------------------------------------------------------------------
data("eukaryotes")
data("bacteria")

## ------------------------------------------------------------------------
data("soil")
data("climat")
data("geography")

## ------------------------------------------------------------------------
library(vegan)

bac.hellinger = decostand(bacteria,method ="hellinger")
euk.hellinger = decostand(eukaryotes,method ="hellinger")

## ------------------------------------------------------------------------
bac.bray = vegdist(bac.hellinger,method = "bray")
euk.bray = vegdist(euk.hellinger,method = "bray")

## ------------------------------------------------------------------------
soil.rescaled   = scale(soil,   center = TRUE, scale = TRUE)
climat.rescaled = scale(climat, center = TRUE, scale = TRUE)

## ------------------------------------------------------------------------
data = procmod.frame(euk       = euk.bray,
                     bac       = bac.bray,
                     climat    = climat,
                     soil      = soil,
                     geography = geography)

## ------------------------------------------------------------------------
euk.pm = pm(formula = euk ~ soil + climat + geography, data = data)
euk.pm

## ------------------------------------------------------------------------
plot(euk.pm)

## ------------------------------------------------------------------------
anova(euk.pm)

